@@ -6,6 +6,7 @@
 #  Department of Chemical Engineering, MIT
 
 from math import sqrt
+from typing import List, Optional
 from molSimplify.Classes.globalvars import globalvars
 
 
@@ -23,17 +24,26 @@ class atom3D:
             partialcharge : int, optional
                 Charge assigned to atom when added to mol. Default is None.
     """
-    def __init__(self, Sym='C', xyz=None, name=False, partialcharge=None, Tfactor=0, greek='', occup=1.00, loc='', line=""):
+    def __init__(self,
+                 Sym: str = 'C',
+                 xyz: Optional[List[float]] = None,
+                 name: Optional[str] = None,
+                 partialcharge: Optional[float] = None,
+                 Tfactor=0,
+                 greek='',
+                 occup=1.00,
+                 loc='',
+                 line=""):
 
         # Element symbol
         self.sym = Sym
-        self.partialcharge = None
+        self.partialcharge = partialcharge
         globs = globalvars()
         amass = globs.amass()
         if Sym not in amass:  # assign default values if not in dictionary
             print(("We didn't find the atomic mass of %s in the dictionary. Assigning default value of 12!\n" % (Sym)))
             # Atomic mass
-            self.mass = 12  # default atomic mass
+            self.mass = 12.0  # default atomic mass
             # Atomic number
             self.atno = 6  # default atomic number
             # Covalent radius
@@ -45,12 +55,12 @@ class atom3D:
         # Flag for freezing in optimization
         self.frozen = False
         # Flag for atom name
+        # NOTE: does not compare to None because empty string would not be valid and
+        # some parts of molSimplify still instantiate atom3D with name=False
         if name:
             self.name = name
         else:
             self.name = Sym
-        # flag for metal
-        self.metal = None
 
         # Coordinates
         if xyz is None:
@@ -79,19 +89,15 @@ class atom3D:
         self.line = line
 
     def __repr__(self):
-        """Returns all bound methods of the mol3D class..
+        return f"atom3D(Sym={self.sym}, xyz={self.__xyz})"
 
-        Returns
-        -------
-            method_string : string
-                String of methods available in mol3D class.
-        """
-
-        method_string = "\nClass atom3D has the following methods:\n"
-        for method in dir(self):
-            if callable(getattr(self, method)):
-                method_string += method + '\n'
-        return method_string
+    # TODO: uncomment this once protein3D has a better implementation than
+    # hashing of a mutable object!
+    # def __eq__(self, other):
+    #     if isinstance(other, self.__class__):
+    #         return self.__dict__ == other.__dict__
+    #     else:
+    #         return False
 
     def coords(self):
         """ Get coordinates of a given atom.
@@ -104,7 +110,7 @@ class atom3D:
         x, y, z = self.__xyz
         return [x, y, z]
 
-    def distance(self, atom2):
+    def distance(self, atom2) -> float:
         """ Get distance from one atom3D class to another.
 
         Parameters
@@ -146,7 +152,7 @@ class atom3D:
         dz = xyz[2]-point[2]
         return [dx, dy, dz]
 
-    def ismetal(self, transition_metals_only=True):
+    def ismetal(self, transition_metals_only=True) -> bool:
         """ Identify whether an atom is a metal.
 
         Parameters
@@ -159,12 +165,7 @@ class atom3D:
             metal : bool
                 Bool for whether or not an atom is a metal.
         """
-        if self.metal is None:
-            if self.sym in globalvars().metalslist(transition_metals_only=transition_metals_only):
-                self.metal = True
-            else:
-                self.metal = False
-        return self.metal
+        return self.sym in globalvars().metalslist(transition_metals_only=transition_metals_only)
 
     def setcoords(self, xyz):
         """ Set coordinates of an atom3D class to a new location.
@@ -178,7 +179,7 @@ class atom3D:
         self.__xyz[1] = xyz[1]
         self.__xyz[2] = xyz[2]
 
-    def symbol(self):
+    def symbol(self) -> str:
         """ Return symbol of atom3D.
 
         Returns
