@@ -6,7 +6,7 @@
 #  Dpt of Chemical Engineering, MIT
 
 # imports
-from molSimplify.Classes.AA3D import AA3D
+from molSimplify.Classes.monomer3D import monomer3D
 from molSimplify.Classes.mol3D import mol3D
 from molSimplify.Classes.atom3D import atom3D
 from molSimplify.Classes.helpers import read_atom, makeMol
@@ -22,7 +22,6 @@ import ast
 import time
 from scipy.spatial import ConvexHull
 # from pymol import cmd, stored
-
 # no GUI support for now
 
 
@@ -34,13 +33,13 @@ class protein3D:
     """
 
     def __init__(self, pdbCode='undef'):
-        # Number of amino acids
+        # Number of monomers
         self.naas = 0
         # Number of heteromolecules
         self.nhetmols = 0
         # Number of chains
         self.nchains = 0
-        # Dictionary of amino acids
+        # Dictionary of monomers
         self.aas = {}
         # Dictionary of all atoms
         self.atoms = {}
@@ -52,7 +51,7 @@ class protein3D:
         self.chains = {}
         # Dictionary of missing atoms
         self.missing_atoms = {}
-        # List of missing amino acids
+        # List of missing monomers
         self.missing_aas = []
         # List of chain locations with more than one conformation
         self.conf = []
@@ -82,25 +81,27 @@ class protein3D:
         self.hull = []
 
     def setAAs(self, aas):
-        """ Set amino acids of a protein3D class to different amino acids.
+        """
+        Set monomers of a protein3D class to different monomers.
 
         Parameters
         ----------
-            aas : dictionary
-                Keyed by chain and location
-                Valued by AA3D amino acids
+        aas : dictionary
+            Keyed by chain and location
+            Valued by monomer3D monomers (amino acids or nucleotides)
         """
         self.aas = aas
         self.naas = len(aas)
 
     def setAtoms(self, atoms):
-        """ Set atom indices of a protein3D class to atoms.
+        """
+        Set atom indices of a protein3D class to atoms.
 
         Parameters
         ----------
-            atoms : dictionary
-                Keyed by atom index
-                Valued by atom3D atom that has that index
+        atoms : dictionary
+            Keyed by atom index
+            Valued by atom3D atom that has that index
         """
         self.atoms = atoms
 
@@ -109,69 +110,75 @@ class protein3D:
 
         Parameters
         ----------
-            a_ids : dictionary
-                Keyed by atom3D atom
-                Valued by its index
+        a_ids : dictionary
+            Keyed by atom3D atom
+            Valued by its index
         """
         self.a_ids = a_ids
 
     def setHetmols(self, hetmols):
-        """ Set heteromolecules of a protein3D class to different ones.
+        """
+        Set heteromolecules of a protein3D class to different ones.
 
         Parameters
         ----------
-            hetmols : dictionary
-                Keyed by chain and location
-                Valued by mol3D heteromolecules
+        hetmols : dictionary
+            Keyed by chain and location
+            Valued by mol3D heteromolecules
         """
         self.hetmols = hetmols
         self.nhetmols = len(hetmols.keys())
 
     def setChains(self, chains):
-        """ Set chains of a protein3D class to different chains.
+        """
+        Set chains of a protein3D class to different chains.
 
         Parameters
         ----------
-            chains : dictionary
-                Keyed by desired chain IDs.
-                Valued by the list of molecules in the chain.
+        chains : dictionary
+            Keyed by desired chain IDs.
+            Valued by the list of molecules in the chain.
         """
         self.chains = chains
         self.nchains = len(chains.keys())
 
     def setMissingAtoms(self, missing_atoms):
-        """ Set missing atoms of a protein3D class to a new dictionary.
+        """
+        Set missing atoms of a protein3D class to a new dictionary.
 
         Parameters
         ----------
-            missing_atoms : dictionary
-                Keyed by amino acid residues of origin
-                Valued by missing atoms
+        missing_atoms : dictionary
+            Keyed by amino acid residues / nucleotides of origin
+            Valued by missing atoms
         """
         self.missing_atoms = missing_atoms
 
     def setMissingAAs(self, missing_aas):
-        """ Set missing amino acids of a protein3D class to a new list.
+        """
+        Set missing amino acids of a protein3D class to a new list.
 
         Parameters
         ----------
-            missing_aas : list
-                List of missing amino acids.
+        missing_aas : list
+            List of missing amino acids.
         """
         self.missing_aas = missing_aas
 
     def setConf(self, conf):
-        """ Set possible conformations of a protein3D class to a new list.
+        """
+        Set possible conformations of a protein3D class to a new list.
 
         Parameters
         ----------
-            conf : list
-                List of possible conformations for applicable amino acids.
+        conf : list
+            List of possible conformations for applicable amino acids.
         """
         self.conf = conf
 
     def autoChooseConf(self):
-        """ Automatically choose the conformation of a protein3D class
+        """
+        Automatically choose the conformation of a protein3D class
         instance based first on what the greatest occupancy level is and then
         the first conformation ihe alphabet with all else equal.
 
@@ -198,77 +205,87 @@ class protein3D:
                                 c_ids.append(self.getIndex(j))
                         # print(c_ids)
                         self.stripAtoms(c_ids)
-                        if type(li) == AA3D and li in self.aas[c]:
+                        if type(li) == monomer3D and li in self.aas[c]:
                             self.aas[c].remove(li)
                         elif type(li) == mol3D and li in self.hetmols[c]:
                             self.hetmols[c].remove(li)
         self.setConf([])
 
     def setR(self, R):
-        """ Set R value of protein3D class.
+        """
+        Set R value of protein3D class.
 
         Parameters
         ----------
-            R : float
-                The desired new R value.
+        R : float
+            The desired new R value.
         """
         self.R = R
 
     def setRfree(self, Rfree):
-        """ Set Rfree value of protein3D class.
+        """
+        Set Rfree value of protein3D class.
 
         Parameters
         ----------
-            Rfree : float
-                The desired new Rfree value.
+        Rfree : float
+            The desired new Rfree value.
         """
         self.Rfree = Rfree
 
     def setRSRZ(self, RSRZ):
-        """ Set RSRZ score of protein3D class.
+        """
+        Set RSRZ score of protein3D class.
 
         Parameters
         ----------
-            RSRZ : float
-                The desired new RSRZ score.
+        RSRZ : float
+            The desired new RSRZ score.
         """
         self.RSRZ = RSRZ
 
     def getMissingAtoms(self):
-        """ Get missing atoms of a protein3D class.
+        """
+        Get missing atoms of a protein3D class.
 
-        Example demonstration of this method:
+        Examples
+        --------
         >>> pdb_system = protein3D()
-        >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
-        >>> for symbol_list in pdb_system.getMissingAtoms():
-        >>>     for symbol in symbol_list:
-        >>>         print(symbol.sym) # Prints the symbol of missing atom
-        >>>         print(symbol.coords()) # Prints the coordinates of the missing atom - they are all the
-        >>>                         # coordinates of origin by default (0.0,0.0,0.0) for missing atoms
+        >>> pdb_system.fetch_pdb('1MH1') # Fetch a PDB
+        fetched: 1MH1
+        >>> missing_atoms = pdb_system.getMissingAtoms()
+
+        List atoms in the first set of missing_atoms
+        >>> [atom.sym for atom in list(missing_atoms)[0]]
+        ['C', 'C', 'C', 'C', 'C', 'C', 'O']
         """
         return self.missing_atoms.values()
 
     def getMissingAAs(self):
-        """ Get missing amino acid residues of a protein3D class.
-
-        Example demonstration of this method:
+        """
+        Get missing amino acid residues of a protein3D class.
 
+        Examples
+        --------
         >>> pdb_system = protein3D()
-        >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
-        >>> pdb_system.getMissingAAs()   # This gives a list of AA3D objects
-        >>> [pdb_system.getMissingAAs()[x].three_lc for x in range(len(val.getMissingAAs()))] # This returns
-        >>>                     # the list of missing AAs by their 3-letter codes
+        >>> pdb_system.fetch_pdb('1MH1') # Fetch a PDB
+        fetched: 1MH1
+        >>> pdb_system.getMissingAAs()   # This gives a list of monomer3D objects
+        [monomer3D(VAL, id=182), monomer3D(LYS, id=183), monomer3D(LYS, id=184)]
         """
         return self.missing_aas
 
     def countAAs(self):
-        """ Return the number of amino acid residues in a protein3D class.
-
-        Example demonstration of this method:
+        """
+        Return the number of amino acid residues in a protein3D class.
 
+        Examples
+        --------
         >>> pdb_system = protein3D()
         >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
+        fetched: 1os7
         >>> pdb_system.countAAs() # This return the number of AAs in the PDB for all the chains.
+        1121
         """
         return self.naas
 
@@ -279,22 +296,26 @@ class protein3D:
 
         Parameters
         ----------
-            sym : str
-                element symbol, default as X.
-            aa : boolean
-                True if we want atoms contained in amino acids
-                False if we want atoms contained in heteromolecules
+        sym : str
+            element symbol, default as X.
+        aa : boolean
+            True if we want atoms contained in amino acids
+            False if we want atoms contained in heteromolecules
 
         Returns
-        ----------
-            inds: list
-                a list of atom indices with the specified symbol.
+        -------
+        inds: list
+            a list of atom indices with the specified symbol.
 
-        Example demonstration of this method:
+        Examples
+        --------
         >>> pdb_system = protein3D()
         >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
+        fetched: 1os7
         >>> pdb_system.findAtom(sym="S", aa=True) # Returns indices of sulphur atoms present in amino acids
+        [2166, 4442, 6733, 9041]
         >>> pdb_system.findAtom(sym="S", aa=False) # Returns indices of sulphur atoms present in heteromolecules
+        [9164, 9182, 9200]
         """
         inds = []
         if aa:
@@ -319,19 +340,25 @@ class protein3D:
 
         Parameters
         ----------
-            three_lc: str
-                three-letter code, default as XAA.
+        three_lc: str
+            three-letter code, default as XAA.
 
         Returns
         -------
-            inds: set
-                a set of amino acid indices with the specified symbol.
+        inds: set
+            a set of amino acid indices with the specified symbol.
 
-        Example demonstration of this method:
+        Examples
+        --------
         >>> pdb_system = protein3D()
         >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
-        >>> pdb_system.findAA(three_lc = 'MET') # Returns a set of pairs where each pair is a combination of the chain name
-        >>>                              # and the index of the amino acid specified (in this case, 'MET')
+        fetched: 1os7
+
+        Return a set of pairs where each pair is a combination of the chain name and
+        the index of the amino acid specified (in this case, 'MET')
+        >>> aa_set = pdb_system.findAA(three_lc = 'MET')
+        >>> sorted(aa_set)  # Sorting for reproducible order in doctest
+        [('A', 268), ('B', 268), ('C', 268), ('D', 268)]
         """
         inds = set()
         for aa in self.aas.values():
@@ -340,53 +367,74 @@ class protein3D:
         return inds
 
     def getChain(self, chain_id):
-        # BUGGY
-        """ Takes a chain of interest and turns it into its own protein3D class instance.
+        """
+        Takes a chain of interest and turns it into its own protein3D class instance.
 
         Parameters
         ----------
-            chain_id : string
-                The letter name of the chain of interest
+        chain_id : string
+            The letter name of the chain of interest
 
         Returns
         -------
-            p : protein3D
-                A protein3D instance consisting of just the chain of interest
+        p : protein3D
+            A protein3D instance consisting of just the chain of interest
 
-        Example demonstration of this method:
+        Examples
+        --------
         >>> pdb_system = protein3D()
         >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
-        >>> pdb_system.getChain('A') # Get chain A of the PDB
+        fetched: 1os7
+        >>> pdb_system.getChain('A') # doctest: +SKIP
         """
         p = protein3D()
+        p.setPDBCode(self.pdbCode)
         p.setChains({chain_id: self.chains[chain_id]})
-        p.setAAs(set(self.chains[chain_id]))
         p.setR(self.R)
         p.setRfree(self.Rfree)
+
         missing_aas = []
         for aa in self.missing_aas:
             if aa.chain == chain_id:
                 missing_aas.append(aa)
         p.setMissingAAs(missing_aas)
+
+        aas = {}
+        for aa in self.aas:
+            if aa[0] == chain_id:
+                aas[aa] = self.aas[aa]
+        p.setAAs(aas)
+
         gone_atoms = {}
         for aa in self.missing_atoms.keys():
-            if aa.chain == chain_id:
+            if aa[0] == chain_id:
                 gone_atoms[aa] = self.missing_atoms[aa]
         p.setMissingAtoms(gone_atoms)
-        gone_hets = self.hetatms
+
+        hets_flipped = {value[0]: key for key, value in self.hetmols.items()}
         atoms = {}
+        a_ids = {}
+        hets = {}
         for a_id in self.atoms:
-            aa = self.getResidue(a_id)
-            if aa is not None:
+            aa = self.getMolecule(a_id)
+
+            if type(aa) == monomer3D:
                 if aa.chain == chain_id:
                     atoms[a_id] = self.atoms[a_id]
+                    a_ids[self.atoms[a_id]] = a_id
             else:
-                if chain_id not in gone_hets[(a_id, self.atoms[a_id])]:
-                    del gone_hets[(a_id, self.atoms[a_id])]
-                else:
+                if aa not in hets_flipped:
+                    print(a_id)
+                het = hets_flipped[aa]
+                het_chain_id = het[0]
+                if het_chain_id == chain_id:
+                    hets[het] = self.hetmols[het]
                     atoms[a_id] = self.atoms[a_id]
-        p.setHetatms(gone_hets)
+                    a_ids[self.atoms[a_id]] = a_id
+
+        p.setHetmols(hets)
         p.setAtoms(atoms)
+
         bonds = {}
         for a in self.bonds.keys():
             if a in p.atoms.values():
@@ -395,40 +443,50 @@ class protein3D:
                     if b in p.atoms.values():
                         bonds[a].add(b)
         p.setBonds(bonds)
+
+        p.setIndices(a_ids)
+        p.setConf([conf for conf in self.conf if conf[0] == chain_id])
+
         return p
 
     def getMolecule(self, a_id, aas_only=False):
-        """ Finds the molecule that the atom is contained in.
+        """
+        Finds the molecule that the atom is contained in.
 
         Parameters
         ----------
-            a_id : int
-                the index of the desired atom whose molecule we want to find
-            aas_only : boolean
-                True if we want ito find atoms contained in amino acids only.
-                False if we want atoms contained in all molecules. Default is False.
+        a_id : int
+            The index of the desired atom whose molecule we want to find
+        aas_only : boolean
+            True if we want ito find atoms contained in amino acids only.
+            False if we want atoms contained in all molecules. Default is False.
 
         Returns
         -------
-            mol : AA3D or mol3D
-                the amino acid residue or heteromolecule containing the atom
+        mol : monomer3D or mol3D
+            The amino acid residue, nucleotide, or heteromolecule containing the atom
 
-        Example demonstration of this method:
+        Examples
+        --------
         >>> pdb_system = protein3D()
         >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
-        >>> pdb_system.getMolecule(a_id=2166) # This returns an molSimplify.Classes.AA3D.AA3D obejct indicating
-        >>>                                   # we that the atom is part of an amino acid
-        >>> pdb_system.getMolecule(a_id=2166).three_lc() # This prints the three letter code of the amino acid of which
-        >>>                                              # atom 2166 is a part of
-        >>> pdb_system.getMolecule(a_id=9164) # This returns a mol3D object indicating that the atom is part of a molecule
-        >>>                                   # that is not an amino acid
+        fetched: 1os7
+
+        This returns an molSimplify.Classes.monomer3D object indicating that the atom is part of an amino acid or nucleotide:
+        >>> pdb_system.getMolecule(a_id=2166)
+        monomer3D(MET, id=268)
+
+        This returns a mol3D object indicating that the atom is part of a molecule that is not an amino acid or nucleotide
+        >>> pdb_system.getMolecule(a_id=9164)
+        mol3D(S1O3N1C2)
         >>> pdb_system.getMolecule(a_id=9164).name # This prints the name of the molecule, in this case, it is 'TAU'
+        'TAU'
         """
         for s in self.aas.values():
-            for mol in s:  # mol is AA3D
+            for mol in s:  # mol is monomer3D
                 if (a_id, self.atoms[a_id]) in mol.atoms:
                     return mol
-        for mol in self.missing_atoms.keys():  # mol is incomplete AA3D
+        for mol in self.missing_atoms.keys():  # mol is incomplete monomer3D
             if (a_id, self.atoms[a_id]) in self.missing_atoms[mol]:
                 return mol
         if not aas_only:
@@ -439,16 +497,19 @@ class protein3D:
         return None  # something is wrong
 
     def stripAtoms(self, atoms_stripped):
-        """ Removes certain atoms from the protein3D class instance.
+        """
+        Removes certain atoms from the protein3D class instance.
 
         Parameters
         ----------
-            atoms_stripped : list
-                list of atom3D indices that should be removed
+        atoms_stripped : list
+            List of atom3D indices that should be removed
 
-        Example demonstration of this method:
+        Examples
+        --------
         >>> pdb_system = protein3D()
         >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
+        fetched: 1os7
         >>> pdb_system.stripAtoms([2166, 4442, 6733, 2165]) # This removes the list of atoms with
         >>>                                                # indices listedin the code
         """
@@ -517,19 +578,22 @@ class protein3D:
         self.setIndices(a_ids)
 
     def stripHetMol(self, hetmol):
-        """ Removes all heteroatoms part of the specified heteromolecule from
+        """
+        Removes all heteroatoms part of the specified heteromolecule from
             the protein3D class instance.
 
         Parameters
         ----------
-            hetmol : str
-                String representing the name of a heteromolecule whose
-                heteroatoms should be stripped from the protein3D class instance
+        hetmol : str
+            String representing the name of a heteromolecule whose
+            heteroatoms should be stripped from the protein3D class instance
 
-        Example demonstration of this method:
+        Examples
+        --------
         >>> pdb_system = protein3D()
-        >>> pdb_system.fetch_pdb('1os7') # Fetch a PDB
-        >>> pdb_system.stripHetMol()
+        >>> pdb_system.fetch_pdb('3I40') # Fetch a PDB
+        fetched: 3I40
+        >>> pdb_system.stripHetMol('HOH')
         """
         hets = self.hetmols.copy()
         for k in hets.keys():
@@ -541,24 +605,32 @@ class protein3D:
                     for a in m.atoms:
                         ids.append(self.a_ids[a])
                     self.stripAtoms(ids)
-                    del self.hetmols[k]
+                    try:  # RM 2023/04/22: I don't think this is necessary as stripAtoms takes care of deleting the hetmol
+                        del self.hetmols[k]
+                    except KeyError:
+                        pass
 
     def findMetal(self, transition_metals_only=True):
-        """Find metal(s) in a protein3D class.
+        """
+        Find metal(s) in a protein3D class.
+
         Parameters
         ----------
-            transition_metals_only : bool, optional
-                Only find transition metals. Default is true.
+        transition_metals_only : bool, optional
+            Only find transition metals. Default is true.
 
         Returns
         -------
-            metal_list : list
-                List of indices of metal atoms in protein3D.
-
-        Example of fetching a PDB file:
+        metal_list : list
+            List of indices of metal atoms in protein3D.
 
+        Examples
+        --------
         >>> pdb_system = protein3D()
         >>> pdb_system.fetch_pdb('1os7')
+        fetched: 1os7
+        >>> pdb_system.findMetal()
+        [9160, 9178, 9196, 9214]
         """
         if not self.metals:
             metal_list = []
@@ -572,80 +644,84 @@ class protein3D:
         return (self.metals)
 
     def freezeatom(self, atomIdx):
-        """Set the freeze attribute to be true for a given atom3D class.
+        """
+        Set the freeze attribute to be true for a given atom3D class.
 
         Parameters
         ----------
-            atomIdx : int
-                Index for atom to be frozen.
+        atomIdx : int
+            Index for atom to be frozen.
         """
 
         self.atoms[atomIdx].frozen = True
 
     def freezeatoms(self, Alist):
-        """Set the freeze attribute to be true for a given set of atom3D classes,
+        """
+        Set the freeze attribute to be true for a given set of atom3D classes,
         given their indices. Preserves ordering, starts from largest index.
 
         Parameters
         ----------
-            Alist : list
-                List of indices for atom3D instances to remove.
+        Alist : list
+            List of indices for atom3D instances to remove.
         """
 
         for h in sorted(Alist, reverse=True):
             self.freezeatom(h)
 
     def getAtom(self, idx):
-        """Get atom with a given index.
+        """
+        Get atom with a given index.
 
         Parameters
         ----------
-            idx : int
-                Index of desired atom.
+        idx : int
+            Index of desired atom.
 
         Returns
         -------
-            atom : atom3D
-                atom3D class for element at given index.
+        atom : atom3D
+            atom3D class for element at given index.
 
         """
         return self.atoms[idx]
 
     def getIndex(self, atom):
-        """ Get index of a given atom
+        """
+        Get index of a given atom
 
         Parameters
         ----------
-            atom : atom3D
-                atom3D class for element at given index.
+        atom : atom3D
+            atom3D class for element at given index.
 
         Returns
         -------
-            idx : int
-                Index of desired atom.
+        idx : int
+            Index of desired atom.
 
         """
         if hasattr(self, 'a_ids') and atom in self.a_ids.keys():
             idx = self.a_ids[atom]
         else:
-            print(atom.sym)
             idx = list(self.atoms.keys())[list(self.atoms.values()).index(atom)]
         return idx
 
     def getBoundMols(self, h_id, aas_only=False):
-        """Get a list of molecules bound to a heteroatom, usually a metal.
+        """
+        Get a list of molecules bound to a heteroatom, usually a metal.
 
         Parameters
         ----------
-            h_id : int
-                the index of the desired (hetero)atom origin
-            aas_only : boolean
-                whether or not to only consider amino acids, defaults False
+        h_id : int
+            The index of the desired (hetero)atom origin
+        aas_only : boolean
+            Whether or not to only consider amino acids, defaults False
 
         Returns
         -------
-            bound_mols : list
-                list of AA3D and/or mol3D instances of molecules bound to hetatm
+        bound_mols : list
+            List of monomer3D and/or mol3D instances of molecules bound to hetatm
         """
         bound_mols = []
         for b_id in self.atoms.keys():
@@ -658,13 +734,14 @@ class protein3D:
         return bound_mols
 
     def readfrompdb(self, text):
-        """ Read PDB into a protein3D class instance.
+        """
+        Read PDB into a protein3D class instance.
 
         Parameters
         ----------
-            text : str
-                String of path to PDB file. Path may be local or global.
-                May also be the text of a PDB file from the internet.
+        text : str
+            String of path to PDB file. Path may be local or global.
+            May also be the text of a PDB file from the internet.
         """
 
         # read in PDB file
@@ -730,8 +807,11 @@ class protein3D:
                     text = text.replace(line, '')
                 sp = line.split()
                 if len(sp) > 2:
-                    a = AA3D(sp[0], sp[1], sp[2])
-                    missing_aas.append(a)
+                    res_num = int(sp[2])
+                    # Ignoring expression tags which are negative residues
+                    if res_num > 0:
+                        a = monomer3D(sp[0], sp[1], sp[2])
+                        missing_aas.append(a)
 
         # start getting missing atoms
         if "M RES CSSEQI  ATOMS" in text:
@@ -753,7 +833,7 @@ class protein3D:
                         if atom != enter and atom[0] in ['C', 'N', 'O', 'H']:
                             missing_atoms[(sp[1], sp[2])].append(
                                 atom3D(Sym=atom[0], greek=atom))
-        # start getting amino acids and heteroatoms
+        # start getting amino acids, nucleotides and heteroatoms
         pa_dict = {'AltLoc': ""}
         if "ENDMDL" in text:
             text.split("ENDMDL")
@@ -835,12 +915,13 @@ class protein3D:
         self.setBonds(bonds)
 
     def fetch_pdb(self, pdbCode):
-        """ API query to fetch a pdb and write it as a protein3D class instance
+        """
+        API query to fetch a pdb and write it as a protein3D class instance
 
         Parameters
         ----------
-            pdbCode : str
-                code for protein, e.g. 1os7
+        pdbCode : str
+            Code for protein, e.g. 1os7
         """
         remoteCode = pdbCode.upper()
         try:
@@ -861,25 +942,28 @@ class protein3D:
                     print("warning: %s not valid.\n" % pdbCode)
 
     def setBonds(self, bonds):
-        """Sets the bonded atoms in the protein.
+        """
+        Sets the bonded atoms in the protein.
+
         This is effectively the molecular graph.
 
         Parameters
         ----------
-            bonds : dictionary
-                Keyed by atom3D atoms in the protein
-                Valued by a set consisting of bonded atoms
+        bonds : dictionary
+            Keyed by atom3D atoms in the protein
+            Valued by a set consisting of bonded atoms
         """
         self.bonds = bonds
 
     def readMetaData(self):
-        """ API query to fetch XML data from a pdb and add its useful attributes
+        """
+        API query to fetch XML data from a pdb and add its useful attributes
         to a protein3D class.
 
         Parameters
         ----------
-            pdbCode : str
-                code for protein, e.g. 1os7
+        pdbCode : str
+            Code for protein, e.g. 1os7
         """
         pdbCode = self.pdbCode
         try:
@@ -890,11 +974,13 @@ class protein3D:
             print("warning: %s not found.\n" % pdbCode)
         else:
             try:
-                ### We then use beautiful soup to read the XML doc. LXML is an XML reader. The soup object is what we then use to parse!
+                # We then use beautiful soup to read the XML doc. LXML is an XML reader.
+                # The soup object is what we then use to parse!
                 soup = BeautifulSoup(xml_doc.content, 'lxml-xml')
 
-                ### We can then use methods of the soup object to find "tags" within the XML file. This is how we would extract sections.
-                ### This is an example of getting everything with a "sec" tag.
+                # We can then use methods of the soup object to find "tags" within the XML file.
+                # This is how we would extract sections.
+                # This is an example of getting everything with a "sec" tag.
                 body = soup.find_all('wwPDB-validation-information')
                 entry = body[0].find_all("Entry")
                 if "DataCompleteness" not in entry[0].attrs.keys():
@@ -924,45 +1010,50 @@ class protein3D:
                     print("warning: %s not valid.\n" % pdbCode)
 
     def setDataCompleteness(self, DataCompleteness):
-        """ Set DataCompleteness value of protein3D class.
+        """
+        Set DataCompleteness value of protein3D class.
 
         Parameters
         ----------
-            DataCompleteness : float
-                The desired new R value.
+        DataCompleteness : float
+            The desired new R value.
         """
         self.DataCompleteness = DataCompleteness
 
     def setTwinL(self, TwinL):
-        """ Set TwinL score of protein3D class.
+        """
+        Set TwinL score of protein3D class.
 
         Parameters
         ----------
-            TwinL : float
-                The desired new TwinL score.
+        TwinL : float
+            The desired new TwinL score.
         """
         self.TwinL = TwinL
 
     def setTwinL2(self, TwinL2):
-        """ Set TwinL squared score of protein3D class.
+        """
+        Set TwinL squared score of protein3D class.
 
         Parameters
         ----------
-            TwinL2 : float
-                The desired new TwinL squared score.
+        TwinL2 : float
+            The desired new TwinL squared score.
         """
         self.TwinL2 = TwinL2
 
     def setEDIAScores(self):
-        """ Sets the EDIA score of a protein3D class.
+        """
+        Sets the EDIA score of a protein3D class.
 
         Parameters
         ----------
-            pdbCode : string
-                The 4-character code of the protein3D class.
+        pdbCode : string
+            The 4-character code of the protein3D class.
         """
         code = self.pdbCode
-        cmd = 'curl -d \'{"edia":{ "pdbCode":"'+code+'"}}\' -H "Accept: application/json" -H "Content-Type: application/json" -X POST https://proteins.plus/api/edia_rest'
+        cmd = ('curl -d \'{"edia":{ "pdbCode":"'+code+'"}}\' -H "Accept: application/json"'
+               ' -H "Content-Type: application/json" -X POST https://proteins.plus/api/edia_rest -k')
         args = shlex.split(cmd)
         result = subprocess.Popen(args, stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE)
@@ -970,14 +1061,14 @@ class protein3D:
         out, err = result.communicate()
         dict_str = out.decode("UTF-8")
         int_dict = ast.literal_eval(dict_str)
-        res2 = subprocess.Popen(['curl', int_dict['location']],
+        res2 = subprocess.Popen(['curl', '-k', int_dict['location']],
                                 stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         out2, err2 = res2.communicate()
         dict2_str = out2.decode("UTF-8")
         dictionary = ast.literal_eval(dict2_str)
         t = 5  # can change depending on how frequently to loop
         while dictionary["status_code"] == 202:
-            res2 = subprocess.Popen(['curl', int_dict['location']],
+            res2 = subprocess.Popen(['curl', '-k ', int_dict['location']],
                                     stdout=subprocess.PIPE,
                                     stderr=subprocess.PIPE)
             # print('sleeping', t)
@@ -987,7 +1078,8 @@ class protein3D:
             dict2_str = out2.decode("UTF-8")
             dictionary = ast.literal_eval(dict2_str)
         link = dictionary["atom_scores"]
-        df = pd.read_csv(link, error_bad_lines=False)
+        df = pd.read_csv(link, on_bad_lines='skip')
+
         for i, row in df.iterrows():
             EDIA = row["EDIA"]
             index = row["Infile id"]
@@ -1004,12 +1096,13 @@ class protein3D:
                 print("OXT is missing")
 
     def setPDBCode(self, pdbCode):
-        """ Sets the 4-letter PDB code of a protein3D class instance
+        """
+        Sets the 4-letter PDB code of a protein3D class instance
 
         Parameters
         ----------
-            pdbCode : string
-                Desired 4-letter PDB code
+        pdbCode : string
+            Desired 4-letter PDB code
         """
         self.pdbCode = pdbCode
 
@@ -1064,12 +1157,13 @@ class protein3D:
         self.centroid = centroid
 
     def convexhull(self):
-        """Computes convex hull of protein.
+        """
+        Computes convex hull of protein.
 
         Returns
         -------
-            hull : array
-                Coordinates of convex hull.
+        hull : array
+            Coordinates of convex hull.
         """
         points = []
         # loop over atoms in protein
