@@ -392,7 +392,7 @@ def returnXYZandGraph(filename, atoms, cell, fcoords, molgraph):
         cart_coord=np.dot(fcoord,cell)
         coord_list.append([cart_coord[0],cart_coord[1],cart_coord[2]])
     tmpstr=",".join([at for at in atoms])
-    if filename != None:
+    if filename is not None:
         np.savetxt(filename[:-4]+".net",molgraph,fmt="%i",delimiter=",",header=tmpstr)
     return coord_list, molgraph
 
@@ -936,7 +936,7 @@ def get_closed_subgraph(linkers, SBUlist, adj_matrix):
             current_linker_list = current_linker_list-SBUlist
             checked_list.add(start_idx)
             for val in loop_over:
-                if (not val in SBUlist):
+                if val not in SBUlist:
                     current_linker_list.update(np.nonzero(adj_matrix[val])[1]) # np.nonzero(adj_matrix[val])[1] are the indices of atoms with bonds to the atom with index val
             left_to_check = current_linker_list-checked_list-SBUlist # Linker atoms whose connecting atoms still need to be checked.
             if len(left_to_check) == 0:
@@ -1042,7 +1042,7 @@ def disorder_detector(name):
         disordered_atom_types = []
         disordered_atom_occupancies = []
 
-        if occupancy_index != False: # This means that occupancy information is available
+        if occupancy_index: # This means that occupancy information is available
             for idx, at in enumerate(atomlines): # Go through the lines of the cif with atom specific information. Atom by atom.
                 ln=at.strip().split()
 
@@ -1122,7 +1122,7 @@ def remove_undesired_atoms(undesired_indices, allatomtypes, fcoords):
     return allatomtypes_trim, fcoords_trim
 
 
-def overlap_removal(cif_path, new_cif_path, wiggle_room=1):
+def overlap_removal(cif_path, new_cif_path):
     """
     Reads a cif file, removes overlapping atoms, and writes the cif to the provided path.
     For a new CIF, recommended to remove symmetry (either with Vesta or with get_primitive), then run overlap_removal, then run solvent_removal.
@@ -1133,9 +1133,6 @@ def overlap_removal(cif_path, new_cif_path, wiggle_room=1):
         The path of the cif file to be read.
     new_cif_path : str
         The path to which the modified cif file will be written.
-    wiggle_room : float
-        A multiplier that allows for more or less strict bond distance cutoffs.
-        Useful for some trouble CIFs with long bonds.
 
     Returns
     -------
@@ -1155,7 +1152,7 @@ def overlap_removal(cif_path, new_cif_path, wiggle_room=1):
 
     # Assuming that the cif does not have graph information of the structure.
     distance_mat = compute_distance_matrix3(cell_v,cart_coords)
-    adj_matrix, overlap_atoms = compute_adj_matrix(distance_mat, allatomtypes, wiggle_room=wiggle_room, handle_overlap=True)
+    adj_matrix, overlap_atoms = compute_adj_matrix(distance_mat, allatomtypes, handle_overlap=True)
 
     # Dealing with the case of overlapping atoms.
     if len(overlap_atoms) != 0:
@@ -1167,8 +1164,8 @@ def overlap_removal(cif_path, new_cif_path, wiggle_room=1):
 
 def solvent_removal(cif_path, new_cif_path, wiggle_room=1):
     """
-    Reads a cif file, removes floating solvent and overlapping atoms, and writes the cif to the provided path.
-    If MOF has a lot of solvent, you may need to apply this function multiple times.
+    Reads a cif file, removes floating solvent atoms, and writes the cif to the provided path.
+    Assumes cif has P1 symmetry.
 
     Parameters
     ----------
