@@ -3,19 +3,19 @@ from molSimplify.Classes.globalvars import globalvars
 from molSimplify.Classes.ligand import ligand_breakdown, ligand_assign
 from molSimplify.Scripts.geometry import distance
 
-########### UNIT CONVERSION
+# UNIT CONVERSION
 HF_to_Kcal_mol = 627.503
 
 
 def autocorrelation(mol, prop_vec, orig, d, oct=True, catoms=None, use_dist=False):
-    ## this function returns the autocorrelation
-    ## for one atom
+    # this function returns the autocorrelation
+    # for one atom
     # Inputs:
-    #	mol - mol3D class
-    #	prop_vec - vector, property of atoms in mol in order of index
-    #	orig -  int, zero-indexed starting atom
-    #	d - int, number of hops to travel
-    #	oct - bool, if complex is octahedral, will use better bond checks
+    #   mol - mol3D class
+    #   prop_vec - vector, property of atoms in mol in order of index
+    #   orig -  int, zero-indexed starting atom
+    #   d - int, number of hops to travel
+    #   oct - bool, if complex is octahedral, will use better bond checks
     result_vector = np.zeros(d + 1)
     hopped = 0
     active_set = set([orig])
@@ -29,7 +29,7 @@ def autocorrelation(mol, prop_vec, orig, d, oct=True, catoms=None, use_dist=Fals
         hopped += 1
         new_active_set = set()
         for this_atom in active_set:
-            ## prepare all atoms attached to this connection
+            # prepare all atoms attached to this connection
             # print('called in AC')
             this_atoms_neighbors = mol.getBondedAtomsSmart(this_atom, oct=oct)
             for bound_atoms in this_atoms_neighbors:
@@ -46,19 +46,20 @@ def autocorrelation(mol, prop_vec, orig, d, oct=True, catoms=None, use_dist=Fals
         active_set = new_active_set
     return (result_vector)
 
+
 def deltametric(mol, prop_vec, orig, d, oct=True, catoms=None):
-    ## this function returns the deltametric
-    ## over the whole molecule
+    # this function returns the deltametric
+    # over the whole molecule
     # Inputs:
-    #	mol - mol3D class
-    #	prop_vec - vector, property of atoms in mol in order of index
-    #	orig -  int, zero-indexed starting atom
-    #	d - int, number of hops to travel
-    #	oct - bool, if complex is octahedral, will use better bond checks
-    #	if oct:
-    #		print('using OCT delta autocorrelation')
-    #	else:
-    #		print('NOT using OCT delta autocorrelation')
+    #   mol - mol3D class
+    #   prop_vec - vector, property of atoms in mol in order of index
+    #   orig -  int, zero-indexed starting atom
+    #   d - int, number of hops to travel
+    #   oct - bool, if complex is octahedral, will use better bond checks
+    #   if oct:
+    #       print('using OCT delta autocorrelation')
+    #   else:
+    #       print('NOT using OCT delta autocorrelation')
     result_vector = np.zeros(d + 1)
     hopped = 0
     active_set = set([orig])
@@ -68,7 +69,7 @@ def deltametric(mol, prop_vec, orig, d, oct=True, catoms=None):
         hopped += 1
         new_active_set = set()
         for this_atom in active_set:
-            ## prepare all atoms attached to this connection
+            # prepare all atoms attached to this connection
             # print('called in DAC')
             this_atoms_neighbors = mol.getBondedAtomsSmart(this_atom, oct=oct)
             for bound_atoms in this_atoms_neighbors:
@@ -81,6 +82,7 @@ def deltametric(mol, prop_vec, orig, d, oct=True, catoms=None):
         active_set = new_active_set
     return (result_vector)
 
+
 def full_autocorrelation(mol, prop, d, oct=oct, modifier=False, use_dist=False):
     w = construct_property_vector(mol, prop, oct=oct, modifier=modifier)
     index_set = list(range(0, mol.natoms))
@@ -89,9 +91,10 @@ def full_autocorrelation(mol, prop, d, oct=oct, modifier=False, use_dist=False):
         autocorrelation_vector += autocorrelation(mol, w, centers, d, oct=oct, use_dist=use_dist)
     return (autocorrelation_vector)
 
+
 def atom_only_autocorrelation(mol, prop, d, atomIdx, oct=True):
-    ## atomIdx must b either a list of indcies
-    ## or a single index
+    # atomIdx must b either a list of indcies
+    # or a single index
     w = construct_property_vector(mol, prop, oct)
     autocorrelation_vector = np.zeros(d + 1)
     if hasattr(atomIdx, "__len__"):
@@ -102,9 +105,10 @@ def atom_only_autocorrelation(mol, prop, d, atomIdx, oct=True):
         autocorrelation_vector += autocorrelation(mol, w, atomIdx, d, oct=oct)
     return (autocorrelation_vector)
 
-def generate_atomonly_autocorrelations(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Gval = False, polarizability=False):
-    ## this function gets autocorrelations for a molecule starting
-    ## in one single atom only
+
+def generate_atomonly_autocorrelations(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Gval=False, polarizability=False):
+    # # this function gets autocorrelations for a molecule starting
+    # # in one single atom only
     # Inputs:
     #       mol - mol3D class
     #       atomIdx - int, index of atom3D class
@@ -133,6 +137,7 @@ def generate_atomonly_autocorrelations(mol, atomIdx, loud, depth=4, oct=True, Nu
     results_dictionary = {'colnames': colnames, 'results': result}
     return results_dictionary
 
+
 def metal_only_autocorrelation(mol, prop, d, oct=True, catoms=None,
                                func=autocorrelation, modifier=False, allow_multi=False):
     autocorrelation_vector = np.zeros(d+1)
@@ -168,11 +173,11 @@ def autocorrelation_catoms(mol, prop_vec, orig, d, oct=True, catoms=None):
         hopped += 1
         new_active_set = set()
         for this_atom in active_set:
-            ## prepare all atoms attached to this connection
+            # prepare all atoms attached to this connection
             # print('called in AC')
             this_atoms_neighbors = mol.getBondedAtomsSmart(this_atom, oct=oct)
             # print('--1--:', this_atoms_neighbors)
-            if this_atom == orig and (not catoms == None):
+            if this_atom == orig and catoms is not None:
                 this_atoms_neighbors = catoms
             # print('--2--:', this_atoms_neighbors)
             for bound_atoms in this_atoms_neighbors:
@@ -185,6 +190,7 @@ def autocorrelation_catoms(mol, prop_vec, orig, d, oct=True, catoms=None):
         active_set = new_active_set
     return (result_vector)
 
+
 def deltametric_catoms(mol, prop_vec, orig, d, oct=True, catoms=None):
     # Calculate the deltametrics for the orig to certain connecting atoms.
     result_vector = np.zeros(d + 1)
@@ -197,11 +203,11 @@ def deltametric_catoms(mol, prop_vec, orig, d, oct=True, catoms=None):
         hopped += 1
         new_active_set = set()
         for this_atom in active_set:
-            ## prepare all atoms attached to this connection
+            # prepare all atoms attached to this connection
             # print('called in DAC')
             this_atoms_neighbors = mol.getBondedAtomsSmart(this_atom, oct=oct)
             # print('--1--:', this_atoms_neighbors)
-            if this_atom == orig and (not catoms == None):
+            if this_atom == orig and (catoms is not None):
                 this_atoms_neighbors = catoms
             # print('--2--:', this_atoms_neighbors)
             for bound_atoms in this_atoms_neighbors:
@@ -216,8 +222,8 @@ def deltametric_catoms(mol, prop_vec, orig, d, oct=True, catoms=None):
 
 
 def atom_only_deltametric(mol, prop, d, atomIdx, oct=True, modifier=False):
-    ## atomIdx must b either a list of indcies
-    ## or a single index
+    # atomIdx must b either a list of indcies
+    # or a single index
     w = construct_property_vector(mol, prop, oct=oct, modifier=modifier)
 
     deltametric_vector = np.zeros(d + 1)
@@ -234,17 +240,17 @@ def metal_only_deltametric(mol, prop, d, oct=True, catoms=None,
                            func=deltametric, modifier=False, allow_multi=False):
     deltametric_vector = np.zeros(d + 1)
     try:
-        deltametric_vector = np.zeros(d + 1)
         n_met = len(mol.findMetal())
         w = construct_property_vector(mol, prop, oct=oct, modifier=modifier)
         if allow_multi:
             for metal_ind in mol.findMetal():
                 deltametric_vector += func(mol, w, metal_ind, d, oct=oct,
-                                       catoms=catoms)
+                                           catoms=catoms)
             deltametric_vector = np.divide(deltametric_vector, n_met)
         else:
+            metal_ind = mol.findMetal()[0]
             deltametric_vector = func(mol, w, metal_ind, d, oct=oct,
-                                  catoms=catoms)
+                                      catoms=catoms)
     except:
         print('Error, no metal found in mol object!')
         return False
@@ -252,28 +258,28 @@ def metal_only_deltametric(mol, prop, d, oct=True, catoms=None,
 
 
 def construct_property_vector(mol, prop, oct=True, modifier=False):
-    ## assigns the value of property
-    ## for atom i (zero index) in mol
-    ## to position i in returned vector
-    ## can be used to create weighted
-    ## graph representations
-    ## oct - bool, if complex is octahedral, will use better bond checks
-    ## modifier - dict, used to modify prop vector (e.g. for adding
-    ##             ONLY used with  ox_nuclear_charge    ox or charge)
-    ##              {"Fe":2, "Co": 3} etc
+    # assigns the value of property
+    # for atom i (zero index) in mol
+    # to position i in returned vector
+    # can be used to create weighted
+    # graph representations
+    # oct - bool, if complex is octahedral, will use better bond checks
+    # modifier - dict, used to modify prop vector (e.g. for adding
+    #             ONLY used with  ox_nuclear_charge    ox or charge)
+    #              {"Fe":2, "Co": 3} etc
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology',
                        'ox_nuclear_charge', 'size', 'vdwrad', 'group_number', 'polarizability',
                        'bondvalence', 'num_bonds', 'bondvalence_devi', 'bodavrg', 'bodstd', 'charge']
-    ## note that ident just codes every atom as one, this gives
-    ## a purely toplogical index. coord gives the number of
-    ## connecting atom to attom i (similar to Randic index)
+    # note that ident just codes every atom as one, this gives
+    # a purely toplogical index. coord gives the number of
+    # connecting atom to attom i (similar to Randic index)
     # if not oct:
     #     print('NOT using octahedral bonding pattern')
     globs = globalvars()
     prop_dict = dict()
     w = np.zeros(mol.natoms)
     done = False
-    if not prop in allowed_strings:
+    if prop not in allowed_strings:
         print(('error, property  ' + str(prop) + ' is not a vaild choice'))
         print((' options are  ' + str(allowed_strings)))
         return False
@@ -294,8 +300,8 @@ def construct_property_vector(mol, prop, oct=True, modifier=False):
         at_keys = list(globs.amass().keys())
         for keys in at_keys:
             values = globs.amass()[keys][0]
-            prop_dict.update({keys: values}) 
-        ####### 11/06/2019 -- Adjusted Gval RACs to not adjust on oxidation state. Confounded with O RACs. #####
+            prop_dict.update({keys: values})
+        # ###### 11/06/2019 -- Adjusted Gval RACs to not adjust on oxidation state. Confounded with O RACs. #####
         # # else:
         #     at_keys = globs.amass().keys()
         #     for keys in at_keys:
@@ -312,10 +318,10 @@ def construct_property_vector(mol, prop, oct=True, modifier=False):
             for keys in at_keys:
                 values = globs.amass()[keys][1]
                 if keys in list(modifier.keys()):
-                    values -= float(modifier[keys]) # assumes oxidation state provided (i.e. Fe(IV))
+                    values -= float(modifier[keys])  # assumes oxidation state provided (i.e. Fe(IV))
                 prop_dict.update({keys: values})
     elif prop == 'polarizability':
-        prop_dict =  globs.polarizability()
+        prop_dict = globs.polarizability()
         for i, atoms in enumerate(mol.getAtoms()):
             atom_type = atoms.symbol()
             w[i] = prop_dict[atom_type]
@@ -380,31 +386,32 @@ def construct_property_vector(mol, prop, oct=True, modifier=False):
 
 def find_ligand_autocorrelations_oct(mol, prop, loud, depth, name=False,
                                      oct=True, custom_ligand_dict=False):
-    ## this function takes a
-    ## symmetric (axial == axial,
-    ## equatorial == equatorial)
-    ## octahedral complex
-    ## and returns autocorrelations for
-    ## the axial an equatorial ligands
-    ## custom_ligand_dict allows the user to skip the breakdown
-    ## in cases where 3D geo is not correct/formed
-    ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
-    ##                                    ax_con_int_list ,eq_con_int_list
-    ## with types: eq/ax_ligand_list list of mol3D
-    ##             eq/ax_con_int_list list of list/tuple of int e.g,  [[1,2] [1,2]]
+    # this function takes a
+    # symmetric (axial == axial,
+    # equatorial == equatorial)
+    # octahedral complex
+    # and returns autocorrelations for
+    # the axial an equatorial ligands
+    # custom_ligand_dict allows the user to skip the breakdown
+    # in cases where 3D geo is not correct/formed
+    # custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
+    #                                    ax_con_int_list ,eq_con_int_list
+    # with types: eq/ax_ligand_list list of mol3D
+    #             eq/ax_con_int_list list of list/tuple of int e.g,  [[1,2] [1,2]]
     if not custom_ligand_dict:
-        liglist, ligdents, ligcons = ligand_breakdown(mol)
-        ax_ligand_list, eq_ligand_list, ax_natoms_list, eq_natoms_list, ax_con_int_list, eq_con_int_list, ax_con_list, eq_con_list, built_ligand_list = ligand_assign(
+        liglist, ligdents, ligcons = ligand_breakdown(mol, BondedOct=oct)
+        (ax_ligand_list, eq_ligand_list, ax_natoms_list, eq_natoms_list, ax_con_int_list,
+         eq_con_int_list, ax_con_list, eq_con_list, built_ligand_list) = ligand_assign(
             mol, liglist, ligdents, ligcons, loud, name=False)
     else:
         ax_ligand_list = custom_ligand_dict["ax_ligand_list"]
         eq_ligand_list = custom_ligand_dict["eq_ligand_list"]
         ax_con_int_list = custom_ligand_dict["ax_con_int_list"]
         eq_con_int_list = custom_ligand_dict["eq_con_int_list"]
-    ## count ligands
+    # count ligands
     n_ax = len(ax_ligand_list)
     n_eq = len(eq_ligand_list)
-    ## get full ligand AC
+    # get full ligand AC
     ax_ligand_ac_full = []
     eq_ligand_ac_full = []
     for i in range(0, n_ax):
@@ -420,7 +427,7 @@ def find_ligand_autocorrelations_oct(mol, prop, loud, depth, name=False,
             eq_ligand_ac_full += full_autocorrelation(eq_ligand_list[i].mol, prop, depth)
     eq_ligand_ac_full = np.divide(eq_ligand_ac_full, n_eq)
 
-    ## get partial ligand AC
+    # get partial ligand AC
     ax_ligand_ac_con = []
     eq_ligand_ac_con = []
 
@@ -443,28 +450,29 @@ def find_ligand_autocorrelations_oct(mol, prop, loud, depth, name=False,
 
 
 def find_ligand_deltametrics_oct(mol, prop, loud, depth, name=False, oct=True, custom_ligand_dict=False):
-    ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
-    ##                                    ax_con_int_list ,eq_con_int_list
-    ## with types: eq/ax_ligand_list list of mol3D
-    ##             eq/ax_con_int_list list of list/tuple of int e.g,  [[1,2] [1,2]]
-    ## this function takes a
-    ## octahedral complex
-    ## and returns deltametrics for
-    ## the axial an equatorial ligands
+    # custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
+    #                                    ax_con_int_list ,eq_con_int_list
+    # with types: eq/ax_ligand_list list of mol3D
+    #             eq/ax_con_int_list list of list/tuple of int e.g,  [[1,2] [1,2]]
+    # this function takes a
+    # octahedral complex
+    # and returns deltametrics for
+    # the axial an equatorial ligands
     if not custom_ligand_dict:
-        liglist, ligdents, ligcons = ligand_breakdown(mol)
-        ax_ligand_list, eq_ligand_list, ax_natoms_list, eq_natoms_list, ax_con_int_list, eq_con_int_list, ax_con_list, eq_con_list, built_ligand_list = ligand_assign(
+        liglist, ligdents, ligcons = ligand_breakdown(mol, BondedOct=oct)
+        (ax_ligand_list, eq_ligand_list, ax_natoms_list, eq_natoms_list, ax_con_int_list,
+         eq_con_int_list, ax_con_list, eq_con_list, built_ligand_list) = ligand_assign(
             mol, liglist, ligdents, ligcons, loud, name=False)
     else:
         ax_ligand_list = custom_ligand_dict["ax_ligand_list"]
         eq_ligand_list = custom_ligand_dict["eq_ligand_list"]
         ax_con_int_list = custom_ligand_dict["ax_con_int_list"]
         eq_con_int_list = custom_ligand_dict["eq_con_int_list"]
-    ## count ligands
+    # count ligands
     n_ax = len(ax_ligand_list)
     n_eq = len(eq_ligand_list)
 
-    ## get partial ligand AC
+    # get partial ligand AC
     ax_ligand_ac_con = []
     eq_ligand_ac_con = []
 
@@ -488,10 +496,11 @@ def find_mc_eq_ax_deltametrics_oct(mol, prop, loud, depth, name=False, oct=True,
                                    func=deltametric_catoms):
     # For octahedral complexes only.
     # Calculate mc/ax, mc/eq deltametrics.
-    liglist, ligdents, ligcons = ligand_breakdown(mol)
-    ax_ligand_list, eq_ligand_list, ax_natoms_list, eq_natoms_list, ax_con_int_list, eq_con_int_list, ax_con_list, eq_con_list, built_ligand_list = ligand_assign(
+    liglist, ligdents, ligcons = ligand_breakdown(mol, BondedOct=oct)
+    (ax_ligand_list, eq_ligand_list, ax_natoms_list, eq_natoms_list, ax_con_int_list,
+     eq_con_int_list, ax_con_list, eq_con_list, built_ligand_list) = ligand_assign(
         mol, liglist, ligdents, ligcons, loud, name=False)
-    ## shape reduce
+    # shape reduce
     ax_con_list = [x[0] for x in ax_con_list]
     eq_con_list = [x[0] for x in eq_con_list]
     ax_ligand_del_mc = metal_only_deltametric(mol, prop, depth, catoms=ax_con_list, func=func)
@@ -505,10 +514,11 @@ def find_mc_eq_ax_autocorrelation_oct(mol, prop, loud, depth, name=False, oct=Tr
                                       func=autocorrelation_catoms, modifier=False):
     # For octahedral complexes only.
     # Calculate mc/ax, mc/eq deltametrics.
-    liglist, ligdents, ligcons = ligand_breakdown(mol)
-    ax_ligand_list, eq_ligand_list, ax_natoms_list, eq_natoms_list, ax_con_int_list, eq_con_int_list, ax_con_list, eq_con_list, built_ligand_list = ligand_assign(
+    liglist, ligdents, ligcons = ligand_breakdown(mol, BondedOct=oct)
+    (ax_ligand_list, eq_ligand_list, ax_natoms_list, eq_natoms_list, ax_con_int_list,
+     eq_con_int_list, ax_con_list, eq_con_list, built_ligand_list) = ligand_assign(
         mol, liglist, ligdents, ligcons, loud, name=False)
-    ## shape reduce
+    # shape reduce
     ax_con_list = [x[0] for x in ax_con_list]
     eq_con_list = [x[0] for x in eq_con_list]
     ax_ligand_ac_mc = metal_only_autocorrelation(mol, prop, depth, catoms=ax_con_list, func=func, modifier=modifier)
@@ -526,8 +536,8 @@ def generate_mc_eq_ax_deltametrics(mol, loud, depth=4, name=False,
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
     if Gval:
-        allowed_strings+= ['group_number']
-        labels_strings+= ['Gval']
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -553,8 +563,8 @@ def generate_mc_eq_ax_autocorrelation(mol, loud, depth=4, name=False,
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
     if Gval:
-        allowed_strings+= ['group_number']
-        labels_strings+= ['Gval']
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -574,10 +584,10 @@ def generate_mc_eq_ax_autocorrelation(mol, loud, depth=4, name=False,
 
 def generate_all_ligand_autocorrelations(mol, loud, depth=4, name=False, flag_name=False,
                                          custom_ligand_dict=False, NumB=False, Gval=False):
-    ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
-    ##                                    ax_con_int_list ,eq_con_int_list
-    ## with types: eq/ax_ligand_list list of mol3D
-    ##             eq/ax_con_int_list list of list/tuple of int e.g,  [[1,2] [1,2]]
+    # custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
+    #                                    ax_con_int_list ,eq_con_int_list
+    # with types: eq/ax_ligand_list list of mol3D
+    #             eq/ax_con_int_list list of list/tuple of int e.g,  [[1,2] [1,2]]
     result_ax_full = list()
     result_eq_full = list()
     result_ax_con = list()
@@ -586,19 +596,16 @@ def generate_all_ligand_autocorrelations(mol, loud, depth=4, name=False, flag_na
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
     if Gval:
-        allowed_strings+=['group_number']
+        allowed_strings += ['group_number']
         labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
     for ii, properties in enumerate(allowed_strings):
-        ax_ligand_ac_full, eq_ligand_ac_full, ax_ligand_ac_con, eq_ligand_ac_con = find_ligand_autocorrelations_oct(mol,
-                                                                                                                    properties,
-                                                                                                                    loud=loud,
-                                                                                                                    depth=depth,
-                                                                                                                    name=name,
-                                                                                                                    oct=True,
-                                                                                                                    custom_ligand_dict=custom_ligand_dict)
+        (ax_ligand_ac_full, eq_ligand_ac_full,
+         ax_ligand_ac_con, eq_ligand_ac_con) = find_ligand_autocorrelations_oct(mol, properties, loud=loud,
+                                                                                depth=depth, name=name, oct=True,
+                                                                                custom_ligand_dict=custom_ligand_dict)
         this_colnames = []
         for i in range(0, depth + 1):
             this_colnames.append(labels_strings[ii] + '-' + str(i))
@@ -619,10 +626,10 @@ def generate_all_ligand_autocorrelations(mol, loud, depth=4, name=False, flag_na
 
 def generate_all_ligand_deltametrics(mol, loud, depth=4, name=False, flag_name=False,
                                      custom_ligand_dict=False, NumB=False, Gval=False):
-    ## custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
-    ##                                    ax_con_int_list ,eq_con_int_list
-    ## with types: eq/ax_ligand_list list of mol3D
-    ##             eq/ax_con_int_list list of list/tuple of int e.g,  [[1,2] [1,2]]
+    # custom_ligand_dict.keys() must be eq_ligands_list, ax_ligand_list
+    #                                    ax_con_int_list ,eq_con_int_list
+    # with types: eq/ax_ligand_list list of mol3D
+    #             eq/ax_con_int_list list of list/tuple of int e.g,  [[1,2] [1,2]]
 
     result_ax_con = list()
     result_eq_con = list()
@@ -630,8 +637,8 @@ def generate_all_ligand_deltametrics(mol, loud, depth=4, name=False, flag_name=F
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
     if Gval:
-        allowed_strings+= ['group_number']
-        labels_strings+= ['Gval']
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -651,16 +658,17 @@ def generate_all_ligand_deltametrics(mol, loud, depth=4, name=False, flag_name=F
         results_dictionary = {'colnames': colnames, 'result_ax_con': result_ax_con, 'result_eq_con': result_eq_con}
     return results_dictionary
 
+
 def generate_metal_autocorrelations(mol, loud, depth=4, oct=True, flag_name=False,
                                     modifier=False, NumB=False, Gval=False, allow_multi=False):
-    #	oct - bool, if complex is octahedral, will use better bond checks
+    # oct - bool, if complex is octahedral, will use better bond checks
     result = list()
     colnames = []
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
     if Gval:
-        allowed_strings+= ['group_number']
-        labels_strings+= ['Gval']
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -677,6 +685,7 @@ def generate_metal_autocorrelations(mol, loud, depth=4, oct=True, flag_name=Fals
         results_dictionary = {'colnames': colnames, 'results': result}
     return results_dictionary
 
+
 def generate_metal_deltametrics(mol, loud, depth=4, oct=True, flag_name=False,
                                 modifier=False, NumB=False, Gval=False, allow_multi=False):
     #   oct - bool, if complex is octahedral, will use better bond checks
@@ -685,8 +694,8 @@ def generate_metal_deltametrics(mol, loud, depth=4, oct=True, flag_name=False,
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
     if Gval:
-        allowed_strings+= ['group_number']
-        labels_strings+= ['Gval']
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -703,6 +712,7 @@ def generate_metal_deltametrics(mol, loud, depth=4, oct=True, flag_name=False,
         results_dictionary = {'colnames': colnames, 'results': result}
     return results_dictionary
 
+
 def generate_full_complex_autocorrelations(mol, loud,
                                            depth=4, oct=True,
                                            flag_name=False, modifier=False,
@@ -712,8 +722,8 @@ def generate_full_complex_autocorrelations(mol, loud,
     allowed_strings = ['electronegativity', 'nuclear_charge', 'ident', 'topology', 'size']
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
     if Gval:
-        allowed_strings+= ['group_number']
-        labels_strings+= ['Gval']
+        allowed_strings += ['group_number']
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
@@ -737,8 +747,8 @@ def generate_full_complex_autocorrelations(mol, loud,
 
 
 def generate_atomonly_deltametrics(mol, atomIdx, loud, depth=4, oct=True, NumB=False, Gval=False, polarizability=False):
-    ## this function gets deltametrics for a molecule starting
-    ## in one single atom only
+    # this function gets deltametrics for a molecule starting
+    # in one single atom only
     # Inputs:
     #       mol - mol3D class
     #       atomIdx - int, index of atom3D class
@@ -749,7 +759,7 @@ def generate_atomonly_deltametrics(mol, atomIdx, loud, depth=4, oct=True, NumB=F
     labels_strings = ['chi', 'Z', 'I', 'T', 'S']
     if Gval:
         allowed_strings += ['group_number']
-        labels_strings += ['Gval'] 
+        labels_strings += ['Gval']
     if NumB:
         allowed_strings += ["num_bonds"]
         labels_strings += ["NumB"]
